@@ -1,6 +1,4 @@
 pub mod assign_style_required;
 pub mod display_name_and_id;
 pub mod minify;
-pub mod pure;
-pub mod template_literals;
 pub mod transpile_css_prop;
